use std::fmt;
use std::any::Any;
use std::future::Future;

use futures::FutureExt;

use slog::Logger;
use super::auth_capnp::authentication::Client;

pub struct Authentication {
    inner: Client,
}
impl fmt::Debug for Authentication {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        f.debug_struct("Authentication")
            .field("inner", &self.inner.type_id())
            .finish()
    }
}

impl Authentication {
    pub fn new(inner: Client) -> Self {
        Self { inner }
    }

    pub fn mechanisms(&mut self) -> impl Future<Output=Vec<String>> {
        let req = self.inner.mechanisms_request().send().promise;
        req.map(|res| {
            let res = res.unwrap();
            let tmp = res.get().unwrap();
            tmp.get_mechs().unwrap().iter().map(|x| x.unwrap().to_string()).collect()
        })
    }
}
